Name:           brogue
Version:        1.14
Release:        %mkrel 1
Summary:        Roguelike game that favors simplicity over complexity
Group:          Games/Arcade
License:        AGPLv3
URL:            https://sites.google.com/site/broguegame/
Source0:        https://github.com/tmewett/BrogueCE/archive/refs/tags/v%{version}/%{name}-%{version}.tar.gz
Source1:        brogue-wrapper.sh
Patch1:         0001-Fix-clang-error-with-incompatible-function-pointer-types.patch

BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(zlib)

%description
Brogue is a direct descendant of Rogue, unlike other popular modern
roguelikes, and it favors simplicity over complexity, while trying
to ensure that the interactions between components will be interesting
and varied.

It is possible to play entirely with the keyboard or entirely with
the mouse or a combination of the two as the player chooses.

Brogue can be played either with a libtcod/SDL or a ncurses interface.
See `brogue --help' for more information.

%prep
%autosetup -p1 -n BrogueCE-%{version}

cp bin/keymap.txt bin/keymap

%build
%make_build DATADIR=%{_gamesdatadir}/%{name} \
            RELEASE=YES \
            DEBUG=YES \
            TERMINAL=YES \
            CFLAGS="%{optflags}" \
            LDFLAGS="%{ldflags}"
%install
# Launch game via a wrapper script and install binary in %%_libexecdir
install -D -m755 bin/%{name} %{buildroot}%{_libexecdir}/%{name}/%{name}

install -D -m755 %{SOURCE1} %{buildroot}%{_gamesbindir}/%{name}

# Install data files
install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -a bin/assets/ \
      bin/keymap \
      %{buildroot}%{_gamesdatadir}/%{name}/

# Icon and desktop entry
install -D -m644 bin/assets/icon.png %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}.png

install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=Brogue
GenericName=Roguelike
Comment=Brave the Dungeons of Doom!
Exec=%{name}
Icon=%{name}
Type=Application
Categories=Game;RolePlaying;
Terminal=false
EOF

%files
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{_datadir}/applications/%{name}.desktop
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_iconsdir}/hicolor/256x256/apps/%{name}.png
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/%{name}


%changelog
* Mon Aug 19 2024 daviddavid <daviddavid> 1.14-1.mga10
+ Revision: 2087048
- new version: 1.14

* Sun Feb 04 2024 daviddavid <daviddavid> 1.13-1.mga10
+ Revision: 2037011
- new version: 1.13
- switch to sdl2

* Fri Apr 01 2022 umeabot <umeabot> 1.7.5-5.mga9
+ Revision: 1839225
- Mageia 9 Mass Rebuild

* Wed Oct 21 2020 akien <akien> 1.7.5-4.mga8
+ Revision: 1637588
- Fix build with GCC 10
+ joequant <joequant>
- fix common
- fix gcc10 compile

* Sat Feb 15 2020 umeabot <umeabot> 1.7.5-3.mga8
+ Revision: 1527754
- Mageia 8 Mass Rebuild

* Wed Jul 24 2019 daviddavid <daviddavid> 1.7.5-2.mga8
+ Revision: 1423813
- add missing BR on pkgconfig(zlib) to fix build

* Mon Oct 01 2018 akien <akien> 1.7.5-1.mga7
+ Revision: 1314060
- Version 1.7.5
- Build against bundled libtcod-1.5.2, not compatible with newer SDL2-based versions (mga#23471)

* Sat Sep 22 2018 umeabot <umeabot> 1.7.4-9.mga7
+ Revision: 1295682
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 wally <wally> 1.7.4-8.mga7
+ Revision: 1237890
- build using our compile flags

* Mon Jun 18 2018 wally <wally> 1.7.4-7.mga7
+ Revision: 1237885
- fix build

* Sun Jan 08 2017 akien <akien> 1.7.4-6.mga6
+ Revision: 1080639
- Patch 3: Fix build against libtcod 1.6.2

* Sat Oct 29 2016 akien <akien> 1.7.4-5.mga6
+ Revision: 1063939
- BR sdl even though libtcod itself uses sdl2
- Rebuild for libtcod 1.6.1

* Sat Apr 02 2016 pterjan <pterjan> 1.7.4-4.mga6
+ Revision: 997676
- Remove march=i586 from the Makefile

* Tue Feb 09 2016 umeabot <umeabot> 1.7.4-3.mga6
+ Revision: 950974
- Mageia 6 Mass Rebuild

* Thu Nov 27 2014 akien <akien> 1.7.4-2.mga5
+ Revision: 799583
- Brogue seed catalog.txt is a documentation file

* Thu Nov 27 2014 akien <akien> 1.7.4-1.mga5
+ Revision: 799562
- Add documentation
- imported package brogue

